Changelog
=========

1.3.0b3 (2025-02-14)
--------------------
- Drop support for Python 3.8
- 100% code linting.
- Copyright year update.
- Setup (dependencies) update.

1.3.0b2 (2024-08-13)
--------------------
- Add support for Python 3.12 and 3.13
- Drop support for Python 3.7
- Add support for PyPy 3.9 and 3.10
- Drop support for PyPy 3.7 and 3.8
- Setup (dependencies) update.

1.3.0b1 (2022-09-10)
--------------------
- | Support for libpcap.set_buffer_size() via 'buffer_size'
  | (optional) pcap constructor's parameter.
- | Added 'datalink' optional parameter to pcap constructor
  | (thank you very much easy-easy@Github for the patch!).
- Tox configuration has been moved to pyproject.toml

1.2.3b14 (2022-08-30)
---------------------
- Update for libpcap>=1.11.0b6
- Add support for Python 3.10 and 3.11
- Add preliminary support for PyPy 3.7, 3.8 and 3.9
- Setup update (currently based mainly on pyproject.toml).

1.2.3b12 (2022-01-19)
---------------------
- | Fixed a bug in pcap.sendpacket()
  | (thank you very much EvanSonnemans@Github
  | for report and bugfix!).

1.2.3b11 (2022-01-10)
---------------------
- Update for libpcap>=1.11.0b3
- Drop support for Python 3.6.
- Copyright year update.
- Setup update.

1.2.3b9 (2021-11-10)
--------------------
- Update for libpcap>=1.11.0b2
- Copyright year update.
- Fixes for Linux.
- Setup update.

1.2.3b5 (2020-10-18)
--------------------
- Add support for Python 3.9.
- Drop support for Python 3.5.
- | Fixed a critical setup of 'libpcap' package
  | (thank you very much msrst@Github!).
- General update and cleanup.
- Fixed docs setup.

1.2.3b1 (2019-11-14)
--------------------
- Update for PyPCAP 1.2.3.
- Add support for Python 3.8.
- Drop support for Python 2.
- Drop support for Python 3.4.
- Update required setuptools version.
- Setup improvements and cleanup.

1.2.0b5 (2018-11-08)
--------------------
- Update required setuptools version.
- Minor setup and tests improvements.

1.2.0b4 (2018-02-26)
--------------------
- Improve and simplify setup and packaging.

1.2.0b3 (2018-02-01)
--------------------
- Update for PyPCAP 1.2.0.

1.2.0b2 (2017-10-10)
--------------------
- Minor changes.

1.2.0b1 (2017-10-05)
--------------------
- Next beta release.
- Update for PyPCAP 1.2.0rc.

1.1.6b4 (2017-10-04)
--------------------
- Fourth beta release.

1.1.6b3 (2017-08-28)
--------------------
- Third beta release.

1.1.6b2 (2017-08-28)
--------------------
- Second beta release.

1.1.6b1 (2017-08-27)
--------------------
- First beta release.

1.1.6a15 (2017-08-25)
---------------------
- Next alpha release.

1.1.6a0 (2017-06-10)
--------------------
- First alpha release.

0.0.1 (2016-09-23)
------------------
- Initial release.
